==> com.liferay.faces.bridge.impl-4.1.3-sources.jar: com/liferay/faces/bridge/internal/BridgeEventHandlerFactoryImpl.java <==
/**
 * Copyright (c) 2000-2019 Liferay, Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.liferay.faces.bridge.internal;

import java.io.Serializable;

import javax.portlet.PortletConfig;
import javax.portlet.faces.BridgeEventHandler;

import com.liferay.faces.bridge.BridgeEventHandlerFactory;
import com.liferay.faces.util.logging.Logger;
import com.liferay.faces.util.logging.LoggerFactory;


/**
 * @author  Neil Griffin
 */
public class BridgeEventHandlerFactoryImpl extends BridgeEventHandlerFactory implements Serializable {

	// serialVersionUID
	private static final long serialVersionUID = 6020555749253211761L;

	// Logger
	private static final Logger logger = LoggerFactory.getLogger(BridgeEventHandlerFactoryImpl.class);

	@Override
	public BridgeEventHandler getBridgeEventHandler(PortletConfig portletConfig) {

		BridgeEventHandler bridgeEventHandler = null;

		// TCK: initMethodTest
		String bridgeEventHandlerClass = portletConfig.getInitParameter("javax.portlet.faces.bridgeEventHandler");

		if (bridgeEventHandlerClass != null) {

			ClassLoader contextClassLoader = Thread.currentThread().getContextClassLoader();

			try {
				Class<?> clazz = contextClassLoader.loadClass(bridgeEventHandlerClass);
				bridgeEventHandler = (BridgeEventHandler) clazz.newInstance();
			}
			catch (Exception e) {
				logger.error(e);
			}
		}

		return bridgeEventHandler;
	}

	@Override
	public BridgeEventHandlerFactory getWrapped() {

		// Since this is the factory instance provided by the bridge, it will never wrap another factory.
		return null;
	}
}

==> com.liferay.faces.bridge.impl-4.1.4-sources.jar: com/liferay/faces/bridge/internal/BridgeEventHandlerFactoryImpl.java <==
/**
 * Copyright (c) 2000-2019 Liferay, Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.liferay.faces.bridge.internal;

import java.io.Serializable;

import javax.portlet.PortletConfig;
import javax.portlet.faces.BridgeEventHandler;

import com.liferay.faces.bridge.BridgeEventHandlerFactory;
import com.liferay.faces.bridge.util.internal.TCCLUtil;
import com.liferay.faces.util.logging.Logger;
import com.liferay.faces.util.logging.LoggerFactory;


/**
 * @author  Neil Griffin
 */
public class BridgeEventHandlerFactoryImpl extends BridgeEventHandlerFactory implements Serializable {

	// serialVersionUID
	private static final long serialVersionUID = 6020555749253211761L;

	// Logger
	private static final Logger logger = LoggerFactory.getLogger(BridgeEventHandlerFactoryImpl.class);

	@Override
	public BridgeEventHandler getBridgeEventHandler(PortletConfig portletConfig) {

		BridgeEventHandler bridgeEventHandler = null;

		// TCK: initMethodTest
		String bridgeEventHandlerClass = portletConfig.getInitParameter("javax.portlet.faces.bridgeEventHandler");

		if (bridgeEventHandlerClass != null) {

			try {
				Class<?> clazz = TCCLUtil.loadClassFromContext(getClass(), bridgeEventHandlerClass);
				bridgeEventHandler = (BridgeEventHandler) clazz.newInstance();
			}
			catch (Exception e) {
				logger.error(e);
			}
		}

		return bridgeEventHandler;
	}

	@Override
	public BridgeEventHandlerFactory getWrapped() {

		// Since this is the factory instance provided by the bridge, it will never wrap another factory.
		return null;
	}
}
